@@ -1,8 +1,9 @@
+from collections import defaultdict
+
 import re
 import threading
 import time
 import weakref
-from collections import defaultdict
 from collections.abc import MutableMapping
 
 
@@ -198,7 +199,7 @@ def valid_response_type(value, nested=False):
     if isinstance(value, NoResponse) and not nested:
         return True
     if (value is not None
-            and not isinstance(value, (bytes, SimpleString, SimpleError, int, list))):
+            and not isinstance(value, (bytes, SimpleString, SimpleError, float, int, list))):
         return False
     if isinstance(value, list):
         if any(not valid_response_type(item, True) for item in value):
